@@ -67,6 +67,8 @@ def dtype_to_ctype(dtype):
         return "std::complex<float>"
     elif dtype == numpy.complex128:
         return "std::complex<double>"
+    elif dtype == numpy.void:
+        return "void"
     else:
         raise ValueError("unable to map dtype '%s'" % dtype)
 
@@ -303,7 +305,7 @@ class Pointer(NestedDeclarator):
 class RestrictPointer(Pointer):
     def get_decl_pair(self):
         sub_tp, sub_decl = self.subdecl.get_decl_pair()
-        return sub_tp, ("*restrict %s" % sub_decl)
+        return sub_tp, ("*__restrict__ %s" % sub_decl)
 
     mapper_method = "map_restrict_pointer"
 
